@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Help;
 
-our $DATE = '2014-12-23'; # DATE
-our $VERSION = '0.01'; # VERSION
+our $DATE = '2015-01-15'; # DATE
+our $VERSION = '0.02'; # VERSION
 
 use 5.010001;
 use strict;
@@ -24,6 +24,9 @@ $SPEC{gen_help} = {
         program_summary => {
             schema => 'str*',
         },
+        subcommands => {
+            schema => 'hash',
+        },
         meta => {
             summary => 'Function metadata, must be normalized',
             schema => 'hash*',
@@ -89,10 +92,18 @@ sub gen_help {
         push @help, "  $usage\n";
     }
 
+    # subcommands
+    {
+        my $subcommands = $args{subcommands} or last;
+        push @help, "Subcommands:\n";
+        for (sort keys %$subcommands) {
+            push @help, "  $_\n";
+        }
+    }
+
     # example
     {
         last unless @{ $clidocdata->{examples} };
-        push @help, "\n";
         push @help, "Examples:\n";
         my $i = 0;
         my $egs = $clidocdata->{examples};
@@ -139,7 +150,7 @@ sub gen_help {
                 (my $b_without_dash = $b) =~ s/^-+//;
                 lc($a) cmp lc($b);
             } @opts;
-            push @help, "\n$cat:\n";
+            push @help, "$cat:\n";
             for my $opt (@opts) {
                 my $ospec = $opts->{$opt};
                 my $arg_spec = $ospec->{arg_spec};
@@ -207,7 +218,7 @@ Perinci::CmdLine::Help - Generate help message for Perinci::CmdLine-based app
 
 =head1 VERSION
 
-This document describes version 0.01 of Perinci::CmdLine::Help (from Perl distribution Perinci-CmdLine-Help), released on 2014-12-23.
+This document describes version 0.02 of Perinci::CmdLine::Help (from Perl distribution Perinci-CmdLine-Help), released on 2015-01-15.
 
 =head1 DESCRIPTION
 
@@ -220,7 +231,7 @@ formatting options first though).
 
 =head2 gen_help(%args) -> [status, msg, result, meta]
 
-Generate help message for Perinci::CmdLine-based app.
+{en_US Generate help message for Perinci::CmdLine-based app}.
 
 Arguments ('*' denotes required arguments):
 
@@ -230,7 +241,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<meta>* => I<hash>
 
-Function metadata, must be normalized.
+{en_US Function metadata, must be normalized}.
 
 =item * B<per_arg_json> => I<bool>
 
@@ -240,9 +251,9 @@ Function metadata, must be normalized.
 
 =item * B<program_summary> => I<str>
 
-=back
+=item * B<subcommands> => I<hash>
 
-Return value:
+=back
 
 Returns an enveloped result (an array).
 
@@ -253,7 +264,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 =for Pod::Coverage ^()$
 
@@ -281,7 +292,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
